# llm_foundation


## Build

```
pixi install
```

## Test

```
pixi r pytest
```

### Development

```
# Increment version
pixi project version patch
pixi install
git add .
git commit -m "xxxx < Intentional >
git push origin main
```
